function [MechEns] = alignSortMechData(DataMech,Settings)
%alignSortMechData Align and sort the (bio)mechanical data
%   Analyze the (bio)mechanical data in the time-domain by aligning data at
%   stretch/perturbation onsets and sorting them into ensembles linked to
%   various perturbation characteristics.
%
%	SYNTAX
%   [MechEns] = alignSortMechData(DataMech,Settings)
%
%	INPUTS
%	DataMech = Selection of (bio)mechanical signals (struct)
%   Settings = Overview of all processing settings (struct)
%
%   OUTPUT
%   MechEns = Aligned and sorted (bio)mechanical signals (struct)

    % Create processing settings and time vector
    segStart = round(Settings.tSegStart/DataMech.dt);
    segEnd   = round(Settings.tSegEnd/DataMech.dt);
    MechEns.tSeg = (-segStart:segEnd-1)'*DataMech.dt;
    
    % Low-pass filter to help obtain velocity/acceleration
    [tfFiltNum,tfFiltDen] = dZOHLpFilter(Settings.fcLpPos*2*pi,1,DataMech.dt);
    posLp = filtfilt(tfFiltNum,tfFiltDen,DataMech.posMeas);
    % Calculate velocity/acceleration with numerical differentiation
    velLpGrad = gradient(posLp)/DataMech.dt;
    accLpGrad = gradient(velLpGrad)/DataMech.dt;

    % Retrieve mechanical start indices for stretch reflexes
    MechEns.StretchIdxs = getStretchIndices(DataMech.posRef,segStart,segEnd,DataMech.dt);

    for ii = 1:numel(Settings.sortFields)
        % Pre-allocate ensemble data structure
        MechEns.(Settings.sortFields{ii}) = struct('posRef',{},'pos',{},'vel',{},'acc',{},'tq',{},'tqComp',{});
        % Retrieve all the seperate mechanical responses to all pulses/steps
        MechEns.(Settings.sortFields{ii}) = getMechStretchEnsembles(MechEns.StretchIdxs.(Settings.sortFields{ii}),MechEns.(Settings.sortFields{ii})...
            ,segStart,segEnd,DataMech.dt,DataMech.posRef,DataMech.posMeas,DataMech.velMeas,accLpGrad,DataMech.tqMeas);
    end
end