function [StoreData] = getMechStretchEnsembles(mechIdx,StoreData,segStart,segEnd,dtMech,posRef,posMeas,velMeas,accMeas,tqMeas)
%getMechStretchEnsembles Retrieve (bio)mechanical response ensembles to stretches
%   Retrieve all the seperate mechanical response ensembles to all stretches
%   starting at the provided mechanical data indices.
%
%	SYNTAX
%   [StoreData] = getMechStretchEnsembles(mechIdx,storeData,segStart,segEnd,dtMech,posRef,posMeas,velMeas,accMeas,tqMeas)
%
%	INPUTS
%   mechIdx   = Set of start indices for stretch reflexes in mechanial data (Mx1 double)
%	StoreData = Total ensembled, segmented (bio)mechanical dataset (struct)
%   segStart  = Number of samples before mechIdx at start of segments (double)
%   segEnd    = Number of samples after mechIdx at end of segments (double)
%   dtMech    = Sampling time mechanical data [s] (double)
%   posRef    = Reference position vector for motor (Mx1 double)
%   posMeas   = Measured position vector at motor encoder (Mx1 double)
%   velMeas   = Measured velocity vector at motor encoder (Mx1 double)
%   accMeas   = Measured acceleration vector at motor encoder (Mx1 double)
%   tqMeas    = Measured torque vector at force sensor (Mx1 double)
%
%   OUTPUT
%	StoreData = Total ensembled, segmented (bio)mechanical dataset (struct)

    % Pre-allocate the output
    StoreData(1).posRef = zeros(segStart+segEnd,numel(mechIdx));
    StoreData.pos       = zeros(segStart+segEnd,numel(mechIdx));
    StoreData.vel       = zeros(segStart+segEnd,numel(mechIdx));
    StoreData.acc       = zeros(segStart+segEnd,numel(mechIdx));
    StoreData.tq        = zeros(segStart+segEnd,numel(mechIdx));
    for jj = 1:numel(mechIdx)
        % Windows given via segStart/segEnd variables
        StoreData.posRef(:,jj) = posRef(mechIdx(jj)+(-segStart:segEnd-1));
        StoreData.pos(:,jj)    = posMeas(mechIdx(jj)+(-segStart:segEnd-1));
        StoreData.vel(:,jj)    = velMeas(mechIdx(jj)+(-segStart:segEnd-1));
        StoreData.acc(:,jj)    = accMeas(mechIdx(jj)+(-segStart:segEnd-1));
        StoreData.tq(:,jj)     = tqMeas(mechIdx(jj)+(-segStart:segEnd-1));
    end
    % Compute compensated torque (normalized before stretch onset)
    % Note datasets aligned on fall-indices lack normalization, given lack of a common static situation before onset
    meanTqRise = mean(StoreData.tq(segStart - (round(0.04/dtMech):-1:0) + 1,:),1);
    StoreData.tqComp = StoreData.tq - meanTqRise + mean(meanTqRise);
end