function MDD = iccMDD(data)
%iccMDD Intraclass Correlation Coefficient (ICC) and Minimal Detectable Difference (MDD)
%   Compute ICC for two-way random or mixed effects, absolute agreement
%   single rater/measurement, i.e. ICC(2,1) for quantitative data.
%   Additionally, the standard error of mean (SEM) and MDD are extracted
%   based on total data variation and ICC outcome.
%
%	SYNTAX
%   [MDD] = iccMDD(data)
%
%	INPUT
%   data = Experimental dataset with multiple columns (N repetitions) (MxN double)
%
%   OUTPUT
%   MDD = Minimal detectable difference extracted from ICC and SEM (double) 

    % Extract total number of measurements (n) and repetitions (k)
    [n, k] = size(data);
    % Compute total sum of squares (variability) in dataset
    SStotal = var(data(:)) *(n*k - 1);
    % Compute mean of squares of residual (MSR), population (MSC) and of
    % the error (MSE)
    MSR = var(mean(data, 2)) * k;
    MSC = var(mean(data, 1)) * n;
    MSE = (SStotal - MSR *(n - 1) - MSC * (k -1))/ ((n - 1) * (k - 1));
    % Compute the ICC(2,1) = Two-way model, absolute agreement, single rater
    ICC = (MSR - MSE) / (MSR + (k-1)*MSE + k*(MSC-MSE)/n);
    % Compute total standard deviation of dataset
    SD = sqrt(SStotal/(n*k-1));
    % Compute standard error of mean
    SEM = SD*sqrt(1-ICC);
    % Compute minimal detectable difference
    MDD = SEM * 1.96 * sqrt(2);
end