function [hEst,MRed] = irfCorr(u,y,fs,M1,M2)
%irfCorr Identifies Impulse Response Function
%   irfCorr estimates the IRF from u to y for the lags M1:M2. The
%   algorithm computes the IRF directly based on auto- and cross-
%   correlation matrices. The function also provides the estimated IRF
%   order based on the minimum description length (MDL) selection.
%
%	SYNTAX
%   [hEst,MRed] = irfCorr(u,y,fs,M1,M2)
%
%	INPUTS
%	u  = input data [-] (Mx1 double)
%	y  = output data [-] (Mx1 double)
%	fs = sample frequency [Hz] (double)
%	M1 = minimum lag of the IRF [-] (double)
%	M2 = maximum lag of the IRF [-] (double)
%
%	OUTPUTS
%	hEst  = IRF estimate [-] (Nx1 double)
%   MRed  = Order of svd reduction (double)

%   References:
%     D.T. Westwick & R.E. Kearney, "Identification of Nonlinear
%     Physiological Systems", John Wiley & Sons, 2003.

    %% Input analysis
    [N,R] = size(u);
    phiUU = zeros(2*N-1,R);
    phiYU = zeros(2*N-1,R);

    %% Correlation matrices
    for r = 1:R
        % Obtain matrices
        phiUU(:,r) = xcov(u(:,r),'biased'); %XCOV to compensate for potential mean of input
        phiYU(:,r) = xcov(y(:,r),u(:,r),'biased');
    end
    phiUU = mean(phiUU,2);
    phiYU = mean(phiYU,2);

    % Reduce correlation matrices
    PhiUU = toeplitz(phiUU(N:N+M2-M1)); 
    PhiYU = phiYU(N+M1:N+M2);

    %% IRF estimate
    % Compute IRF estimate
    hEst = fs*(PhiUU\PhiYU);

    % Compute SVD
    [U,S,V] = svd(PhiUU);
    L       = length(hEst);

    % Compute variance each singular vector contributes
    gamma = zeros(L,1);
    for i = 1:L
        gamma(i) = S(i,i)*(V(:,i)'*(hEst/fs)).^2;
    end

    % Sort SVD in descending order
    [gammaSort,nSort] = sort(gamma,1,'descend');

    %% Cost function and Order selection
    % Compute variance, required for MDL and AIC
    yVar = var(y);

    % MDL - minimum description length;
    MDL = zeros(L,1);
    % Compute cost function
    for M = 1:L
        MDL(M) = (1 + M*log(N)/N)*(yVar - sum(gammaSort(1:M)));
    end
    % Order selected minimizes MDL
    [~,MRed] = min(MDL);
    % Compute new IRF estimate
    % Reduce SVD matrices using correct indices
    URed = U(:,nSort(1:MRed));
    SRed = S(nSort(1:MRed),nSort(1:MRed));
    VRed = V(:,nSort(1:MRed));

    % Compute reduced auto-correlation matrix
    PhiUUInv = URed*(SRed\VRed');
    
    % Compute final IRF, note phi_uu_inv is the inverse of phi_uu!
    hEst = fs*(PhiUUInv*PhiYU);
end