function [posRisingEdge,tqRisingEdge] = isolateRisingSlope(DataMech,Settings)
%isolateRisingSlope Isolate rising slope(s) for full-ROM movements
%   Isolate the position and torque data from the rising slope(s) present 
%   within full-ROM experimental data. The rising slope(s) are isolated 
%   from 10% to 90% of the ROM. Any dorsiflexion torques (opposite of
%   expected reaction) are eliminated from the results.
%
%	SYNTAX
%   [posRisingEdge,tqRisingEdge] = isolateRisingSlope(DataMech,Settings)
%
%	INPUTS
%	DataMech = Selection of (bio)mechanical signals (struct)
%   Settings = Overview of all processing settings (struct)
%
%   OUTPUTS
%   posRisingEdge = Position data within rising slopes of movement [rad] (Mx1 cell)
%   tqRisingEdge  = Torque data within rising slopes of movement [Nm] (Mx1 cell)

    % ROM Drivefile
    rom = max(DataMech.Drivefile) - min(DataMech.Drivefile);
    % Search all data between 10% to 90% 
    dataPosSelect = find(DataMech.posMeas > (DataMech.posMeas(1) + 0.1*rom) & DataMech.posMeas < (DataMech.posMeas(1) + 0.9*rom));
    % Search for large jumps and store indices at start/end rising slope
    [~,idxSelect] = maxk(diff(dataPosSelect),Settings.spatReps*2-1);
    idxSelect(1:2) = idxSelect(1:2) + 1; % Compensate for indexing
    % Convert to full timeseries indices used isolation
    idxSelect = dataPosSelect([1; sort(idxSelect)]);
    % Pre-allocate
    posRisingEdge = cell(Settings.spatReps,1);
    tqRisingEdge = cell(Settings.spatReps,1);
    for ii = 1:Settings.spatReps
        % Isolate rising slopes
        posRisingEdge{ii} = DataMech.posMeas(idxSelect(2*ii-1):idxSelect(2*ii));
        tqRisingEdge{ii} = DataMech.tqMeas(idxSelect(2*ii-1):idxSelect(2*ii));
        % Eliminate positive (dorsiflexion torques) from analysis
        if (tqRisingEdge{ii} > 0)
            disp('Torque Check')
        end
        posRisingEdge{ii}(tqRisingEdge{ii} > 0) = [];
        tqRisingEdge{ii}(tqRisingEdge{ii} > 0) = [];
    end
end