function [DataMech,Settings] = loadData(dataSet,Settings,anatomicalAngle)
%loadData Load (bio)mechanical
%   Load all the (bio)mechanical data available from experiments and
%   simulation. Relevant signals are selected and stored.
%
%	SYNTAX
%   [DataMech,Settings] = loadData(dataSet,Settings,anatomicalAngle)
%
%	INPUTS
%   dataSet         = (Bio)mechanical data location (string)
%   Settings        = Overview of all processing settings (struct)
%   anatomicalAngle = Translation between Achilles and anatomical angle, meas. with goniometer (2x1 double)
%
%   OUTPUTS
%	DataMech = Selection of (bio)mechanical signals (struct)
%   Settings = Overview of all processing settings (struct)

    % Load (bio)mechanical data
    loadedData = load(dataSet);
    % Time characteristics
    DataMech.dt = 1/loadedData.OutputData.TrialSettings.fsAch; % [s] Achilles Perturbator
    data = loadedData.OutputData.AchData;
    
    % Select (bio)mechanical signals: position/velocity/torque and reference
    DataMech.t = data(:,Settings.mechDataColumns(1));       % [s] Time vector data
    DataMech.posRef  = data(:,Settings.mechDataColumns(2)); % [rad] Position reference
    DataMech.posMeas = data(:,Settings.mechDataColumns(4)); % [rad] Position measured
    DataMech.velRef  = data(:,Settings.mechDataColumns(3)); % [rad/s] Velocity reference
    DataMech.velMeas = data(:,Settings.mechDataColumns(5)); % [rad/s] Velocity measured
    DataMech.tqMeas = data(:,Settings.mechDataColumns(6));  % [Nm] Torque measured
    DataMech.sync = data(:,Settings.mechDataColumns(7));    % [-] Synchronization signal
    DataMech.Drivefile = loadedData.OutputData.Drivefile;   % [rad] Drivefile
    
    % Center positions signals around zero with given perturbation amplitude
    if (Settings.isLocalPosNorm)
        DataMech.posRef = DataMech.posRef - DataMech.posRef(1) - Settings.pertAmpl/2;
        DataMech.posMeas = DataMech.posMeas - DataMech.posMeas(1) - Settings.pertAmpl/2;
        if (~all(mod(DataMech.sync,1) == 0))
            DataMech.sync = DataMech.sync - DataMech.sync(1) - Settings.pertAmpl/2;
        end
    else
        % Center positions around the anatomical angles (with 0 deg
        % refering to a 90deg neutral ankle angle)
        DataMech.posRef = DataMech.posRef - anatomicalAngle(2) + anatomicalAngle(1)/180*pi;
        DataMech.posMeas = DataMech.posMeas - anatomicalAngle(2) + anatomicalAngle(1)/180*pi;
        DataMech.Drivefile = DataMech.Drivefile - DataMech.Drivefile(1);
    end
    % Center torque signal around zero (based on session or local torque norm)
    if (Settings.isLocalTqNorm)
        DataMech.tqMeas = DataMech.tqMeas - loadedData.OutputData.TrialSettings.initialTorque;
    else
        DataMech.tqMeas = DataMech.tqMeas - loadedData.OutputData.SessionSettings.InitialTorque;
    end
    
    if (isfield(loadedData.OutputData.TrialSettings,'pspTStep'))
        % Load Settings
        Settings.nReflIRF = loadedData.OutputData.TrialSettings.pspTStep - 0.01;
    end
end