function [kbi,gozd,VAF,SEM,Settings] = offlineSepStiffIdent(varargin)
%offlineSepStiffIdent Offline estimation of Intrinsic stiffness and Reflexive activity
% 	System identification is used to identify a joint stiffness model based 
%	on two parallel paths (also called parallel-cascade model). The model
%	contains an intrinsic path, identifying a 2nd-order rotation spring(K),
%	damper(B), inertia(I) system, and a reflexive path identifying the 
%	gain (G), frequency (Omega), damping (Zeta) and delay (Delta) of the 
%   impulse response function IRF.
%
%	SYNTAX
%   [~,~,~,~,Settings] = offlineSepStiffIdent(nReflIRF) {Initialization}
%   [kbi,gozd,VAF,SEM,Settings] = offlineSepStiffIdent(pos,vel,tq,Settings) {Execution}
%
%	INPUTS
%   {Initialization}
%   nReflIRF = Length Reflexive IRF [s] (double)
%   {Execution}
%	pos      = Position measurement [rad] (Mx1 double)
%   vel      = Velocity measurement [rad/s] (Mx1 double)
%   tq       = Torque measurement [Nm] (Mx1 double)
%   Settings = Settings used for every function calls (struct)
%
%   OUTPUT
%   kbi      = Identified intrinsic impedence model [Nm/rad; Nm/rad/s; Nm/rad/s^2] (Mx3 double)
%   gozd     = Identified reflexive impedance model [Nm/rad/s; rad/s; -; s] (Mx1 double)
%   VAF      = Variance Accounted For {total,intrinsic,reflexive} (struct)
%   SEM      = Variance Accounted For {intrinsic,reflexive} (struct)
%   Settings = Settings used for every function calls (struct)

    %%% Initialization
    if (nargin == 1)
        nReflIRF = varargin{1};
        % Sampling Times
        Settings.dt = 1/2048; % [s] Achilles, Sampling time experimental data
        Settings.decimationRatio = 14; % [-] ADR-0001, Decimation ratio
        Settings.dtDec = Settings.dt*Settings.decimationRatio; % [s] Sampling time after decimation
        % IRF lengths
        Settings.nIntrIRF = 0.035; % [s] MSc Jeanine, Length intrinsic IRF
        Settings.nReflIRF = nReflIRF; % [s] Reflex IRF length varies for spastic vs. non-spastic
        Settings.nLagIntrIRF = ceil(Settings.nIntrIRF/Settings.dtDec); % [-] Number of samples intrinsic IRF
        Settings.nLagReflIRF = ceil(Settings.nReflIRF/Settings.dtDec); % [-] Number of samples reflexive IRF
        % Voluntary torque
        Settings.isFitVol = 1; % [-] ADR-0003, Voluntary torque compensation within algorithm
        Settings.fcAvgFilt = 0.5; % [Hz] ADR-0003, Voluntary torque estimation filter
        
        % Estimation settings
        Settings.nNonparamIter = 10; % [-] MSc Jeanine, Max. number of iterations non-parameteric part algorithm
        Settings.nNonparamTol  = 0.005; % [-] MSc Jeanine, Threshold to stop iterating non-parameteric part algorithm
        Settings.delayRange = 0.035:0.001:0.065; % [-] MSc Jeanine, Range of neural delay tested in reflexive parametric fit
        Settings.lpReflFilt = 0.1; % [-] ADR-0001, Low-pass filter for reflexive parametric fit, improve SEM/std
        Settings.aaFilt = 0.45; % [-] ADR-0001, manual implementation of decimation ratio

        % Empty system identification parameters for initialization step
        kbi = [];
        gozd = [];
        VAF = [];
        SEM = [];
        
    elseif (nargin == 4)
        % Get variables from function input
        posMeas  = varargin{1};
        velMeas  = varargin{2};
        tqMeas   = varargin{3};
        Settings = varargin{4};
        
        % Averaging filter: Low-pass filter with low cut-off frequency
        [avgFilt.b,avgFilt.a] = butter(2,(Settings.fcAvgFilt*2*Settings.dt),'low');
        % Build low-pass filter settings for decimation
        fcLpInFilt = Settings.aaFilt*(1/Settings.dtDec); % [Hz] Anti-aliasing low-pass filter before decimation
        [lpInFilt.b,lpInFilt.a] = dZOHLpFilter(fcLpInFilt*2*pi,1,Settings.dt); % Critically damped filter
        [filtA,filtB,filtC,filtD] = tf2ss((fcLpInFilt*2*pi)^2,[1 2*fcLpInFilt*2*pi (fcLpInFilt*2*pi)^2]);
        filtD = [filtD; filtC*filtB]; % Adaptation to obtain acceleration
        filtC = [filtC; filtC*filtA]; %     " "
        ssFilt = ss(filtA,filtB,filtC,filtD);
        
        % Process input signals (decimate {lp-filter, downsample})
        pos = downsample(filter(lpInFilt.b,lpInFilt.a,posMeas),Settings.decimationRatio,Settings.decimationRatio-1);
        vel = downsample(filter(lpInFilt.b,lpInFilt.a,velMeas),Settings.decimationRatio,Settings.decimationRatio-1);
        velRect = max(vel,0);
        tq = downsample(filter(lpInFilt.b,lpInFilt.a,tqMeas),Settings.decimationRatio,Settings.decimationRatio-1);
        % Get approximate acceleration from state of low-pass filtered velocity
        filtSignal = lsim(ssFilt*exp(-1/4073*tf('s')),velMeas,(0:numel(velMeas)-1)'*Settings.dt); % Time delay compensation wrt 'filter'
        accMeas = filtSignal(:,2);
        acc = downsample(accMeas,Settings.decimationRatio,Settings.decimationRatio-1);

        % Initialize iterative estimation
        N = numel(pos);
        VAF.maxNP = -1000;
        % Pre-allocate loop-variables
        tqIntr = zeros(numel(tq),Settings.nNonparamIter+1);
        tqRefl = zeros(numel(tq),Settings.nNonparamIter+1);
        tqVol  = zeros(numel(tq),Settings.nNonparamIter+1);
        
        %%% Nonparametric IRF intrinsic, reflexive & voluntary pathways
        for ii = 1:Settings.nNonparamIter
            % Estimate impedance IRF intrinsic pathway
            tqIntr(:,ii+1) = tq - tqRefl(:,ii) - tqVol(:,ii);
            hIntr          = irfCorr(pos,tqIntr(:,ii+1),1/Settings.dtDec,-Settings.nLagIntrIRF,Settings.nLagIntrIRF);
            % Simulate intrinsic pathway
            tqIntrDum      = filter(hIntr,1,[pos;zeros(Settings.nLagIntrIRF+1,1)])*Settings.dtDec;
            tqIntr(:,ii+1) = tqIntrDum((1:N)+Settings.nLagIntrIRF);
            
            % IRF reflex pathway
            tqRefl(:,ii+1) = tq - tqIntr(:,ii+1) - tqVol(:,ii);
            hRefl          = irfCorr(velRect,tqRefl(:,ii+1),1/Settings.dtDec,0,Settings.nLagReflIRF-1);
            % Simulate reflexive pathway
            tqRefl(:,ii+1) = filter(hRefl,1,velRect)*Settings.dtDec;
            
            % Voluntary torque
            if (Settings.isFitVol)
                tqVol(:,ii+1) = tq - tqIntr(:,ii+1) - tqRefl(:,ii+1);
                tqVol(:,ii+1) = [zeros(Settings.nLagIntrIRF,1); filtfilt(avgFilt.b,avgFilt.a,tqVol((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF),ii+1)); zeros(Settings.nLagIntrIRF,1)];
            end
            
            % Compute torques and trim edges (filter effects)
            tqTotal = tqIntr(:,ii+1) + tqRefl(:,ii+1) + tqVol(:,ii+1);
            tqTrim = tq((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF));
            tqIntrTrim = tqIntr((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF),ii+1);
            tqReflTrim = tqRefl((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF),ii+1);
            tqVolTrim  = tqVol((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF),ii+1);
            tqTotalTrim = tqTotal((Settings.nLagIntrIRF+1):(end-Settings.nLagIntrIRF));
            
            % VAF calculations & Tolerance check
            VAF.totalNP = (1 - var(tqTotalTrim-tqTrim)/var(tqTrim))*100;
            if (((VAF.totalNP-VAF.maxNP) < Settings.nNonparamTol) || ...
                (ii == Settings.nNonparamIter))
                % Break loop as max VAF has been reached, save results from
                % iteration with largest VAF
                VAF.totalNP = VAF.maxNP;
                tqIntr = tqIntr(:,ii);
                tqRefl = tqRefl(:,ii);
                tqVol  = tqVol(:,ii);
                break;
            else
                VAF.maxNP = VAF.totalNP; 
                VAF.intrNP = (1 - var(tqIntrTrim-tqTrim)/var(tqTrim))*100;
                VAF.reflNP = (1 - var(tqReflTrim-tqTrim)/var(tqTrim))*100;
                VAF.volNP  = (1 - var(tqVolTrim-tqTrim)/var(tqTrim))*100;
            end
        end
        
        %%% Smooth Reflexive pathway
        fcLpReflFilt = Settings.lpReflFilt*(1/Settings.dtDec);
        [lpReflFilt.b,lpReflFilt.a] = dZOHLpFilter(fcLpReflFilt*2*pi,1,Settings.dtDec);
        tqRefl = filter(lpReflFilt.b,lpReflFilt.a,tqRefl);
        velRect = filter(lpReflFilt.b,lpReflFilt.a,velRect);
        hRefl = irfCorr(velRect,tqRefl,1/Settings.dtDec,0,Settings.nLagReflIRF-1);
                
        %%% Paramteric fit intrinsic pathway
        % Least Squares Fit on intrinsic torque
        kbi = (-[acc,vel,pos]\tqIntr)';
        SEM.Intr = sqrt(sum(([acc,vel,pos]*kbi' - tqIntr).^2)*diag(inv([acc,vel,pos]'*[acc,vel,pos]))/numel(pos));
        
        %%% Paramteric fit reflexive pathway
        % Define error function helpers
        tRefl = (0:numel(hRefl)-1)'*Settings.dtDec;
        s = tf('s');
        xRefl = zeros(3,numel(Settings.delayRange));
        SEM.Refl = zeros(3,numel(Settings.delayRange));
        VAF.reflPd = zeros(numel(Settings.delayRange),1);
        % General options for optimizations
        options = optimset('lsqnonlin');
        options = optimset(options, 'display', 'none');

        for ii = 1:numel(Settings.delayRange)
            delay = Settings.delayRange(ii);
            % Define error function
            errFunRefl = @(param) (hRefl - impulse((-param(1)*param(2)^2)/(s^2 + 2*param(3)*param(2)*s + param(2)^2)*exp(-s*delay),tRefl));
            
            % Define boundaries and initial guess
            lb = [0 0 0];
            ub = [75 50 3];
            x0 = [(0.5+rand)*20 (0.5+rand)*21 (0.5+rand)*0.8];

            % Find parameters where error function = 0 & standard error of estimation
            [xRefl(:,ii),~,resRefl,~,~,~,jacRefl] = lsqnonlin(errFunRefl,x0,lb,ub,options);
            SEM.Refl(:,ii) = full(sqrt(resRefl'*resRefl*(diag(inv(jacRefl'*jacRefl)))/length(resRefl)))';

            % Simulate IRF with estimated parameters
            hReflFit = impulse(-(xRefl(1,ii)*xRefl(2,ii)^2)/(s^2 + 2*xRefl(3,ii)*xRefl(2,ii)*s + xRefl(2,ii)^2)*exp(-s*delay),tRefl);
            VAF.reflPd(ii) = (1 - var(hReflFit-hRefl)/var(hRefl))*100;
        end

        % Select delay with best VAF
        [~,idxVAFd] = max(VAF.reflPd);
        gozd = xRefl(:,idxVAFd); gozd(4) = Settings.delayRange(idxVAFd);
        SEM.Refl = SEM.Refl(:,idxVAFd);
        VAF.reflP = VAF.reflPd(idxVAFd);
        
        %%% Total VAF
        Hact = tf(gozd(2)^2,[1 2*gozd(2)*gozd(3) gozd(2)^2])*exp(-gozd(4)*tf('s'));
        tqSimIntr = -([acc,vel,pos]*kbi');
        tqSimRefl = -(gozd(1)*lsim(Hact,max(vel,0),(0:numel(vel)-1)'*Settings.dtDec));
        tqSimTotal = tqSimIntr + tqSimRefl + tqVol;
        VAF.totalP = (1 - var(tqSimTotal-tq)/var(tq))*100;
        VAF.intrP = (1 - var(tqSimIntr-tqIntr)/var(tqIntr))*100;
        VAF.reflP = (1 - var(tqSimRefl-tqRefl)/var(tqRefl))*100;
        
        % Store relevant VAF parameters for output
        VAF = struct('totalNP',VAF.totalNP,'totalP',VAF.totalP,'intrNP',VAF.intrNP,'reflNP',VAF.reflNP,'volNP',VAF.volNP,'intrP',VAF.intrP,'reflP',VAF.reflP);
    end
end