function [varargout] = shadedErrorBar(x,y,errBar,lineColor,edgeColor,fillColor,varargin)
% generate continuous error bar area around a line plot
%
% function H=shadedErrorBar(x,y,errBar,lineColor,edgeColor,fillColor,...)
%
% Purpose 
% Makes a 2-d line plot with a pretty shaded error bar made
% using patch. Error bar color is chosen automatically.
%
%
% Inputs (required)
% x - vector of x values [optional, can be left empty]
% y - vector of y values or a matrix of n observations by m cases
%     where m has length(x);
% errBar - if a vector we draw symmetric errorbars. If it has a size
%          of [2,length(x)] then we draw asymmetric error bars with
%          row 1 being the upper bar and row 2 being the lower bar
%          (with respect to y). ** alternatively ** errBar can be a
%          cellArray of two function handles. The first defines which
%          statistic the line should be and the second defines the
%          error bar.
% lineColor/edgeColor/fillColor - RGB values for respective colors of the
%          lines, edges and fill to be plotted.
%
% Inputs (optional, param/value pairs)
% 'lineProps' - ['-k' by default] defines the properties of
%             the data line. e.g.:    
%             'or-', or {'-or','markerfacecolor',[1,0.2,0.2]}
%
% Outputs
% H - a structure of handles to the generated plot objects.
%
%
% Rob Campbell - November 2009
% https://nl.mathworks.com/matlabcentral/fileexchange/26311-raacampbell-shadederrorbar
% 
% Edits - Jan 2021: Adapted to fit within personal plotting style and
% ununsed features removed.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Extract values from the inputParser
lineStyles = {'-','--',':','-.'};
lineProps = varargin;

%Process y using function handles if needed to make the error bar
%dynamically
if iscell(errBar) 
    fun1=errBar{1};
    fun2=errBar{2};
    errBar=fun2(y);
    y=fun1(y);
else
    y=y(:).';
end

if isempty(x)
    x=1:length(y);
else
    x=x(:).';
end

%Make upper and lower error bars if only one was specified
if length(errBar)==length(errBar(:))
    errBar=repmat(errBar(:)',2,1);
else
    s=size(errBar);
    f=find(s==2);
    if isempty(f), error('errBar has the wrong size'), end
    if f==2, errBar=errBar'; end
end

if length(x) ~= length(errBar)
    error('length(x) must equal length(errBar)')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot to get the parameters of the line
H.mainLine = plot(x,y,lineProps{:},'Color',lineColor);

%Calculate the error bars
uE = y+errBar(1,:);
lE = y-errBar(2,:);

%Add the patch error bar
holdStatus = ishold;
if ~holdStatus, hold on,  end

%Make the patch
yP = [lE,fliplr(uE)];
xP = [x,fliplr(x)];

%remove nans otherwise patch won't work
xP(isnan(yP))=[];
yP(isnan(yP))=[];

% Create patch of error bar
H.patch = patch(xP,yP,1,'facecolor',fillColor,'edgecolor','none','HandleVisibility','off');

%Make pretty edges around the patch. 
if (isnumeric(edgeColor))
    if (~isempty(lineProps))
        lineStyleIdx = find(strcmp(lineStyles,lineProps{1}));
    end
    if ((isempty(lineProps)) || (isempty(lineStyleIdx)))
        lineStyleIdx = 1;
    end
    H.edge(1) = plot(x,lE,lineStyles{lineStyleIdx},'color',edgeColor,'HandleVisibility','off');
    H.edge(2) = plot(x,uE,lineStyles{lineStyleIdx},'color',edgeColor,'HandleVisibility','off');
end

%Now replace the line (this avoids having to bugger about with z coordinates)
uistack(H.mainLine,'top')
set(gca,'Layer','top');

if ~holdStatus, hold off, end

if (nargout == 1)
    varargout{1} = H;
end