function [rom,workSlow,workFast] = spatWork(DataMechSlow,DataMechFast,DataCalib,subjectWeight,subjectFootlength,Settings)
%spatWork Calculation of work applied by ankle during instrumented SPAT
%   Calculation of work applied by ankle during instrumented SPAT. For the
%   instrumented SPAT a slow and fast passive movement are applied to the
%   joint. The joint's work is extracted between 10% to 90% of the ROM over
%   the rising slopes, i.e. movements towards dorsiflexion.
%
%	SYNTAX
%   [rom,workSlow,workFast] = spatWork(DataMechSlow,DataMechFast,DataCalib,subjectWeight,subjectFootlength,Settings)
%
%	INPUTS
%   DataMechSlow      = Selection of (bio)mechanical signals, slow SPAT velocity (struct)
%   DataMechFast      = Selection of (bio)mechanical signals, fast SPAT velocity (struct)
%   DataCalib         = Selection of (bio)mechanical signals, footplate torque calibration (struct)
%   subjectWeight     = Subject body weight [kg] (double)
%   subjectFootlength = Subject foot length [m] (double)
%   Settings          = Overview of all processing settings (struct)
%
%   OUTPUTS
%   rom      = Range of Motion (ROM) ankle (2x1 double)
%   workSlow = Work applied by ankle for slow passive movement (Mx1 double)
%   workFast = Work applied by ankle for fast passive movement (Mx1 double)

    % Search and isolate for all rising slopes between 10% to 90% amplitude
    [posRisingSlow,tqRisingSlow] = isolateRisingSlope(DataMechSlow,Settings);
    rom = [mean(cellfun(@min,posRisingSlow)) mean(cellfun(@max,posRisingSlow))];
    
    % Search and isolate for all rising slopes between 10% to 90% amplitude
    [posRisingFast,tqRisingFast] = isolateRisingSlope(DataMechFast,Settings);
    
    % Pre-process calibration torque (low-pass filter & zero at starting angle of SPAT)
    [tqFilt.b,tqFilt.a] = butter(2,5*2*DataCalib.dt,'low');
    DataCalib.tqCalib = filtfilt(tqFilt.b,tqFilt.a,DataCalib.tqMeas);
    [~,idxCalib] = unique(DataCalib.posMeas); idxCalib = sort(idxCalib);
    DataCalib.tqCalib = DataCalib.tqCalib - interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),DataMechSlow.posMeas(1));
    % Interpolate calibration torque onto slow/fast movements
    calibTqSlowInterp = cellfun(@(x) interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),x),posRisingSlow,'UniformOutput',false);
    calibTqFastInterp = cellfun(@(x) interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),x),posRisingFast,'UniformOutput',false);
    
    % Foot-Gravity model
    footWeight = 0.0143*subjectWeight;
    footCGArm = subjectFootlength*0.45;
    footTqSlow = cellfun(@(x) footWeight*9.81*(-footCGArm*sin(x)),posRisingSlow,'UniformOutput',false);
    footTqFast = cellfun(@(x) footWeight*9.81*(-footCGArm*sin(x)),posRisingFast,'UniformOutput',false);
    
    % Calculate are between torque curves
    workSlow = cellfun(@(x,y,a,b) trapz(x,-y+a+b-b(1)),posRisingSlow,tqRisingSlow,calibTqSlowInterp,footTqSlow);
    workFast = cellfun(@(x,y,a,b) trapz(x,-y+a+b-b(1)),posRisingFast,tqRisingFast,calibTqFastInterp,footTqFast);
end