%% Clean Start
clc, clearvars, close all;

%% Settings
% Overview of conditions to-be processed
Settings.subjectID = cellstr(num2str([1:4 6:10].', '%03d')); % Subject identifier (padded to 3 numbers)
Settings.sessionID = cellstr(num2str((1:3).', '%02d')); % Session identifier (padded to 2 numbers)

% SPAT settings
Settings.spatReps = 3; % [-] Number of SPAT slow/fast repetitions
% Sys-ID (D03) Perturbation
Settings.pertAmpl = 0.035; % [rad] Amplitude (peak-to-peak)
Settings.rngSeed = 1;      % [-] Random-number generator seed
% Torque normalization
Settings.isLocalTqNorm = 1; % Flag to normalize torque at start trial (if true) or with InitialTorque of session (if false)

% Add folder with all shared functions
addpath(genpath('Functions'));
rng(Settings.rngSeed);

%% Manual Data
% Manual input of all clinical data, measured by clinician/physiotherapist
subjectWeight = [84; 74; 90; 82; 72; 82; 60; 85; 75]; % [kg] Participant body weight
subjectFootlength = [0.256; 0.243; 0.277; 0.286; 0.256; 0.260; 0.254; 0.277; 0.273]; % [m] Participant foot length
anatomicalAngle = [-10,1.0950; ... % [deg] Anatomical angle (column 1) w.r.t. encoder angle (column 2) for all participants
                   -30,0.7803; ...
                   -5,1.2047; ...
                   -15,1.0966; ...
                   -12,1.0966; ...
                   -10,1.0966; ...
                   -25,0.6179; ...
                   -30,0.9219; ...
                   -15,1.0966];

% MAS - SOL: Knee 30deg flexion, targeting Soleus
Data.masSOL = [1.5 2 1.5 2 1   1 1 1 1.5; ...
               1.5 1 1   0 1.5 1 0 0 0; ...
               1.5 2 1   2 1.5 1 1 1 1];
% Tardieu at Velocity 3 (V3): As fast as possible, faster than gravity
Data.tardV3SOL = [3 3 4 1 4 4 1 4 4; ...
                  3 3 4 2 3 3 0 4 3; ...
                  3 4 4 2 2 4 1 4 2];
              
%% Spasticity Analyses
% Pre-allocation
fieldNames = {'rom','intrK','intrKSEM','intrB','intrBSEM','reflG','reflGSEM','vafNP','vafP','vafIntrP','vafReflP'};
for ii = 1:numel(fieldNames)
    Data.(fieldNames{ii}) = zeros(numel(Settings.sessionID),2,numel(Settings.subjectID));
end
fieldNames = {'spatSlowWork','spatFastWork','spatDiffWork'};
for ii = 1:numel(fieldNames)
    Data.(fieldNames{ii}) = zeros(numel(Settings.sessionID),3,numel(Settings.subjectID));
end

for ii = 1:numel(Settings.subjectID)
    for jj = 1:numel(Settings.sessionID)
        %%% SPAT
        % Trial Settings
        Settings.mechDataColumns = [1 6 7 2 3 4 11]; % [-] Columns used to load data [time, posRef, velRef, posMeas, velMeas, tqMeas, Sync]
        Settings.isLocalPosNorm = 0; % Flag to normalize position at start trial (if true) or around the anatomical angles (if false)
        % Retrieve all experimental folders/files
        dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
        dataCD = dataCD(1:fileSepIdxs(end)-1);
        dirContent = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/*.mat']);
        dirContent = {dirContent.name}';
        dirCalibration = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/A05_CaliAchilles/*.mat']);
        dirCalibration = {dirCalibration.name}';
        
        if (jj ~= 3 || ii ~= 8)
            % Load (bio)mechanical data from calibration trial
            dataCalibration = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/A05_CaliAchilles/' dirCalibration{1}];
            Settings.isLocalTqNorm = 0;
            [DataCalib,Settings] = loadData(dataCalibration,Settings,anatomicalAngle(ii,:));
            Settings.isLocalTqNorm = 1;
            % Load (bio)mechanical for slow SPAT trial
            dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/' dirContent{1}];
            [DataMechSlow,Settings] = loadData(dataSet,Settings,anatomicalAngle(ii,:));
            % Load (bio)mechanical for fast SPAT trial
            dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/' dirContent{2}];
            [DataMechFast,~] = loadData(dataSet,Settings,anatomicalAngle(ii,:));
            
            % Analyze SPAT torque
            [Data.rom(jj,:,ii),workSlow,workFast] = spatWork(DataMechSlow,DataMechFast,DataCalib,subjectWeight(ii),subjectFootlength(ii),Settings);
            % Compute SPAT (Work slow movement & Work difference, normalized for ROM and weight)
            Data.spatSlowWork(jj,:,ii) = workSlow/diff(Data.rom(jj,:,ii))/subjectWeight(ii);
            Data.spatFastWork(jj,:,ii) = workFast/diff(Data.rom(jj,:,ii))/subjectWeight(ii);
            Data.spatDiffWork(jj,:,ii) = (workFast - workSlow)/diff(Data.rom(jj,:,ii))/subjectWeight(ii);
        end
        
        %%% Impedance
        % Trial Settings
        Settings.mechDataColumns = [1 6 7 2 3 4 2]; % [-] Columns used to load data [time, posRef, velRef, posMeas, velMeas, tqMeas, Sync]
        Settings.isLocalPosNorm = 1; % Flag to normalize position at start trial (if true) or around the anatomical angles (if false)
        % Retrieve all experimental folders/files
        dirContent = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/D03_OfflineTIIdent/*.mat']);
        dirContent = {dirContent.name}';

        for kk = 1:numel(dirContent)
            dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/D03_OfflineTIIdent/' dirContent{kk}];
            % Load (bio)mechanical
            [DataMech,Settings] = loadData(dataSet,Settings);

            % Post-trial online seperation of intrinsic and reflexive stiffness
            [~,~,~,~,SysIDSettings] = offlineSepStiffIdent(Settings.nReflIRF);
            [DataSysID.kbi,DataSysID.gozd,DataSysID.VAF,DataSysID.SEM,~] = offlineSepStiffIdent(DataMech.posMeas,DataMech.velMeas,DataMech.tqMeas,SysIDSettings);
            
            % Store results (K = Intrinsic Stiffness; G = Reflexive Gain; SEM = Standard Error of Mean)
            Data.intrK(jj,kk,ii)    = DataSysID.kbi(3);
            Data.intrKSEM(jj,kk,ii) = DataSysID.SEM.Intr(3);
            Data.intrB(jj,kk,ii)    = DataSysID.kbi(2);
            Data.intrBSEM(jj,kk,ii) = DataSysID.SEM.Intr(2);
            Data.reflG(jj,kk,ii)    = DataSysID.gozd(1);
            Data.reflGSEM(jj,kk,ii) = DataSysID.SEM.Refl(1);
            Data.vafNP(jj,kk,ii)    = DataSysID.VAF.totalNP;
            Data.vafP(jj,kk,ii)     = DataSysID.VAF.totalP;
            Data.vafIntrP(jj,kk,ii) = DataSysID.VAF.intrP;
            Data.vafReflP(jj,kk,ii) = DataSysID.VAF.reflP;
        end
    end
end

%%% Data Corrections
Data.spatSlowWork(3,:,8) = NaN; Data.spatFastWork(3,:,8) = NaN; Data.spatDiffWork(3,:,8) = NaN; Data.rom(3,:,8) = NaN; % Manual overwrite, calibration issues in S008_Sess03_T3
save('Processed/dataProcessed.mat','Data','-v7.3');

%% Outcome Processing
clearvars; load('Processed/dataProcessed.mat','Data');
% Angle rad->deg
Data.rom = Data.rom*180/pi; % [rad] -> [deg]
% Reshape SPAT/Impedance data for icc computations
retestK = reshape(permute(Data.intrK(:,[1 2],:),[1 3 2]),[],2,1);
retestB = reshape(permute(Data.intrB(:,[1 2],:),[1 3 2]),[],2,1);
retestG = reshape(permute(Data.reflG(:,[1 2],:),[1 3 2]),[],2,1);
retestSPATDiff = reshape(permute(Data.spatDiffWork,[1 3 2]),[],3,1);
retestSPATSlow = reshape(permute(Data.spatSlowWork,[1 3 2]),[],3,1);
retestSPATFast = reshape(permute(Data.spatFastWork,[1 3 2]),[],3,1);
% Average SPAT/Impedance data within-session for between-subject correlations
meanK = squeeze(mean(Data.intrK(:,[1 2],:),2));
meanB = squeeze(mean(Data.intrB(:,[1 2],:),2));
meanG = squeeze(mean(Data.reflG(:,[1 2],:),2));
meanSPATDiff = squeeze(mean(Data.spatDiffWork,2));
meanSPATFast = squeeze(mean(Data.spatFastWork,2));
meanSPATSlow = squeeze(mean(Data.spatSlowWork,2));
% Store data for R
corrData = [Data.masSOL(:), Data.tardV3SOL(:), meanG(:), meanK(:), meanB(:), meanSPATDiff(:), meanSPATFast(:), meanSPATSlow(:)];
save('Processed/dataStats.mat','retestK','retestB','retestG','retestSPATDiff','retestSPATSlow','retestSPATFast','corrData');

%% Within-Subject Statistics
% Reflexive
withinG = reshape(permute(Data.reflG(:,[1 2],:),[2 3 1]),[],3,1); %[1 3 5 6 8 9]
withinSPATDiff = reshape(permute(Data.spatDiffWork,[2 3 1]),[],3,1);
withinSPATDiff = withinSPATDiff(~any(isnan(withinSPATDiff),2),:);
withinTardieu = Data.tardV3SOL';
% Intrinsic
withinK = reshape(permute(Data.intrK(:,[1 2],:),[2 3 1]),[],3,1);
withinSPATSlow = reshape(permute(Data.spatSlowWork,[2 3 1]),[],3,1);
withinSPATSlow = withinSPATSlow(~any(isnan(withinSPATSlow),2),:);
% Overall
withinMAS = Data.masSOL';
withinSPATFast = reshape(permute(Data.spatFastWork,[2 3 1]),[],3,1);
withinSPATFast = withinSPATFast(~any(isnan(withinSPATFast),2),:);

% Friedman Tests
[friedMAS.p,friedMAS.tbl,friedMAS.stats] = friedman(withinMAS,1);
[friedSPATFast.p,friedSPATFast.tbl,friedSPATFast.stats] = friedman(withinSPATFast,3);
[friedTardieu.p,friedTardieu.tbl,friedTardieu.stats] = friedman(withinTardieu,1);
[friedSPATDiff.p,friedSPATDiff.tbl,friedSPATDiff.stats] = friedman(withinSPATDiff,3);
[friedG.p,friedG.tbl,friedG.stats] = friedman(withinG,2);
[friedSPATSlow.p,friedSPATSlow.tbl,friedSPATSlow.stats] = friedman(withinSPATSlow,3);
[friedK.p,friedK.tbl,friedK.stats] = friedman(withinK,2);

% Multiple comparison tests (with bonferroni correction)
[compSPATDiff.c,compSPATDiff.m,compSPATDiff.h,compSPATDiff.gnames] = multcompare(friedSPATDiff.stats,'CType','bonferroni');
[compMAS.c,compMAS.m,compMAS.h,compMAS.gnames] = multcompare(friedMAS.stats,'CType','bonferroni');

%% Correlation Baseline vs. Effect values
% Compute Spearman/Pearson's correlation between baseline value (session 1)
% and effect values (difference sessions 2 or 3 with session 1)
baseValue = [Data.masSOL(1,:); meanSPATFast(1,:); meanSPATSlow(1,:); meanK(1,:); Data.tardV3SOL(1,:); meanSPATDiff(1,:); meanG(1,:)];
effectValue = [Data.masSOL(2:3,:) - Data.masSOL(1,:); 
               meanSPATFast(2:3,:) - meanSPATFast(1,:);
               meanSPATSlow(2:3,:) - meanSPATSlow(1,:);
               meanK(2:3,:) - meanK(1,:);
               Data.tardV3SOL(2:3,:) - Data.tardV3SOL(1,:);
               meanSPATDiff(2:3,:) - meanSPATDiff(1,:);
               meanG(2:3,:) - meanG(1,:)];

% Compute correlations (remove nan from analysis)
corrMatrix = zeros(7,1);
typeCorr = {'Spearman','Pearson','Pearson','Pearson','Spearman','Pearson','Pearson'};
for jj = 1:7
    ii = 1;
    corrEval = [baseValue(jj,:)',effectValue(ii+2*(jj-1),:)']; corrEval = corrEval(~any(isnan(corrEval),2),:);
    corrMatrix(jj) = corr(corrEval(:,1),corrEval(:,2),'type',typeCorr{jj});
end

%% VAF Analysis
% Compute 25-50(median)-75 percentiles of VAF
prcVafP = prctile(reshape(Data.vafP(:,[1 2],:),[],1,1),[25 50 75]);
prcVafIntrP = prctile(reshape(Data.vafIntrP(:,[1 2],:),[],1,1),[25 50 75]);
prcVafReflP = prctile(reshape(Data.vafReflP(:,[1 2],:),[],1,1),[25 50 75]);

%% Figure 4 (Within Botox)
% Compute MDDs for visualization
retestSPATDiff = retestSPATDiff(~any(isnan(retestSPATDiff),2),:);
retestSPATSlow = retestSPATSlow(~any(isnan(retestSPATSlow),2),:);
retestSPATFast = retestSPATFast(~any(isnan(retestSPATFast),2),:);
Data.mddSPATDiff = iccMDD(retestSPATDiff);
Data.mddSPATSlow = iccMDD(retestSPATSlow);
Data.mddSPATFast = iccMDD(retestSPATFast);
Data.mddG = iccMDD(retestG);
Data.mddB = iccMDD(retestB);
Data.mddK = iccMDD(retestK);

% Figure 4
plotWidth    = 20;
plotHeight   = 6;
marginLeft   = 0.9;
marginRight  = 0.1;
marginBottom = 0.5;
marginTop    = 0.5;
nPlotX       = 7;
nPlotY       = 1;
spacingX     = 1.05;
spacingY     = 0.4;
fontSize     = 8;
fontName     = 'Segoe UI';

hAx = gobjects(7,1);
colorsPlot = [plotColors(1,8); plotColors(1,'light'); plotColors(1); ...
              plotColors(2,8); plotColors(2,'light'); plotColors(2); ...
              plotColors(3,8); plotColors(3,'light'); plotColors(3); ...
              plotColors(10,8); plotColors(10,'light'); plotColors(10)];
figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
posSubplots{1} = posSubplots{1} - [0.0025 0 0 0];
posSubplots{2} = posSubplots{2} + [0.0025 0 0 0];
posSubplots{3} = posSubplots{3} + [0.0075 0 0 0];
posSubplots{4} = posSubplots{4} + [0.0037 0 0 0];
rng(1);
xPlot = [0.8*ones(1,9); ones(1,9); 1.2*ones(1,9)] + randn(3,9)/75;
markerStyles = {'o','x','+','*','s','d','v','>','p'};

dataPlot = [Data.masSOL; meanSPATFast; meanSPATSlow; meanK; Data.tardV3SOL; meanSPATDiff; meanG];

%%% Overall
for jj = 1:2
    hAx(jj) = axes('position',posSubplots{jj},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
    for ii = 1:3
        for kk = 1:9
            plot(xPlot(ii,kk),dataPlot(ii+3*(jj-1),kk),'Color',colorsPlot(ii,:),'LineWidth',1,'MarkerSize',7,'Marker',markerStyles{kk});
        end
        plot(mean(xPlot(ii,:)),mean(dataPlot(ii+3*(jj-1),:),'omitnan'),'.','Color',colorsPlot(ii+9,:),'LineWidth',1,'MarkerSize',17);
    end
    plot(xPlot,dataPlot((1:3)+3*(jj-1),:),'Color',plotColors(11,7),'LineWidth',1);
    plot(mean(xPlot,2),mean(dataPlot((1:3)+3*(jj-1),:),2,'omitnan'),'Color','k','LineWidth',1.5);
    switch jj
        case 1
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{MAS}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            ylabel('MAS (-)');
            yticks([0 1 1.5 2]);
            yticklabels({'0','1','1+','2'});
            axis([0.73 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
        case 2
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Fast SPAT (W_{fast})}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            plot([0.7 0.7],0.5*max(max(dataPlot((1:3)+3*(jj-1),:)))+[-Data.mddSPATFast/2 Data.mddSPATFast/2],'Color',plotColors(1),'LineWidth',2);
            ylabel('W_{fast} (Nm/kg)');
            axis([0.67 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
    end
    xticklabels(hAx(jj),{'T0','T1','T2'})
    xticks(0.8:0.2:1.2);
end

%%% Intrinsic
for jj = 3:4
    hAx(jj) = axes('position',posSubplots{jj},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
    for ii = 1:3
        for kk = 1:9
            plot(xPlot(ii,kk),dataPlot(ii+3*(jj-1),kk),'Color',colorsPlot(ii+3,:),'LineWidth',1,'MarkerSize',7,'Marker',markerStyles{kk});
        end
        plot(mean(xPlot(ii,:)),mean(dataPlot(ii+3*(jj-1),:),'omitnan'),'.','Color',colorsPlot(ii+9,:),'LineWidth',1,'MarkerSize',17);
    end
    plot(xPlot,dataPlot((1:3)+3*(jj-1),:),'Color',plotColors(12,7),'LineWidth',1);
    plot(mean(xPlot,2),mean(dataPlot((1:3)+3*(jj-1),:),2,'omitnan'),'Color','k','LineWidth',1.5);
    switch jj
        case 3
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Slow SPAT (W_{slow})}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            plot([0.7 0.7],0.5*max(max(dataPlot((1:3)+3*(jj-1),:)))+[-Data.mddSPATSlow/2 Data.mddSPATSlow/2],'Color',plotColors(2),'LineWidth',2);
            ylabel('W_{slow} (Nm/kg)');
        case 4
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Intr. Stiff (K)}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            plot([0.7 0.7],0.5*max(max(dataPlot((1:3)+3*(jj-1),:)))+[-Data.mddK/2 Data.mddK/2],'Color',plotColors(2),'LineWidth',2);
            ylabel('Intr. Stiff (Nm/rad)');
    end
    axis([0.67 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
    xticklabels(hAx(jj),{'T0','T1','T2'})
    xticks(0.8:0.2:1.2);
end

%%% Reflexive
for jj = 5:7
    hAx(jj) = axes('position',posSubplots{jj},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
    for ii = 1:3
        for kk = 1:9
            plot(xPlot(ii,kk),dataPlot(ii+3*(jj-1),kk),'Color',colorsPlot(ii+6,:),'LineWidth',1,'MarkerSize',7,'Marker',markerStyles{kk});
        end
        plot(mean(xPlot(ii,:)),mean(dataPlot(ii+3*(jj-1),:),'omitnan'),'.','Color',colorsPlot(ii+9,:),'LineWidth',1,'MarkerSize',17);
    end
    plot(xPlot,dataPlot((1:3)+3*(jj-1),:),'Color',plotColors(13,7),'LineWidth',1);
    plot(mean(xPlot,2),mean(dataPlot((1:3)+3*(jj-1),:),2,'omitnan'),'Color','k','LineWidth',1.5);
    switch jj
        case 5
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Tardieu (TS_Q)}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            ylabel('TS_Q (-)');
            axis([0.72 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
        case 6
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Diff. SPAT ({\Delta}W)}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            plot([0.7 0.7],0.5*max(max(dataPlot((1:3)+3*(jj-1),:)))+[-Data.mddSPATDiff/2 Data.mddSPATDiff/2],'Color',plotColors(3),'LineWidth',2);
            ylabel('{\Delta}W (Nm/kg)');
            axis([0.67 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
        case 7
            text(1,1.12*max(max(dataPlot((1:3)+3*(jj-1),:))),'\bf{Refl. Gain (G)}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
            plot([0.7 0.7],0.5*max(max(dataPlot((1:3)+3*(jj-1),:)))+[-Data.mddG/2 Data.mddG/2],'Color',plotColors(3),'LineWidth',2);
            ylabel('Reflex Gain (Nm{\cdot}s/rad)');
            axis([0.67 1.27 0 max(max(dataPlot((1:3)+3*(jj-1),:)))]);
    end
    xticklabels(hAx(jj),{'T0','T1','T2'})
    xticks(0.8:0.2:1.2);
end
    
% export_fig([cd '/Processed/OutcomeFigures/Fig4_WithinBotox'],'-pdf','-painters');

%% Figure 5 (Normalized Within Botox)
% Figure 5
plotWidth    = 4.5;
plotHeight   = 5.5;
marginLeft   = 1;
marginRight  = 0.15;
marginBottom = 0.95;
marginTop    = 0.4;
nPlotX       = 1;
nPlotY       = 1;
spacingX     = 1.35;
spacingY     = 0.4;
fontSize     = 8;
fontName     = 'Segoe UI';

figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
markerStyles = {'o','x','+','*','s','d','v','>','p'};

xPlot = meanG(1,:);
dataPlot = meanG(2:3,:) - meanG(1,:);

%%% Reflexive G
jj = 7;
    axes('position',posSubplots{1},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
    for ii = 1
        for kk = 1:9
            plot(xPlot(:,kk),dataPlot(ii,kk),'Color',plotColors(3),'LineWidth',1,'MarkerSize',7,'Marker',markerStyles{kk});
        end
    end
text(35,14.8,'\bf{Refl. Gain (G)}','FontSize',1.1*fontSize,'FontName',fontName,'HorizontalAlignment','center','VerticalAlignment','top');
xlabel('T0 (Nm{\cdot}s/rad)'); ylabel('T1 - T0 (Nm{\cdot}s/rad)');
axis([0 70 -30 10]);
    
% export_fig([cd '/Processed/OutcomeFigures/Fig5_NormEffectBotox'],'-pdf','-painters');