%% Clean Start
clc, clearvars, close all;

%% Settings
% Overview of conditions to-be processed
Settings.subjectID = cellstr(num2str([7 4].', '%03d')); % Subject identifier (padded to 3 numbers)
Settings.sessionID = cellstr(num2str((1:3).', '%02d')); % Session identifier (padded to 2 numbers)
% Data column/row order settings
Settings.mechDataColumns = [1 6 7 2 3 4 2]; % [-] Columns used to load data [time, posRef, velRef, posMeas, velMeas, tqMeas, Sync]

% Participant Data
subjectWeight = [82; 82]; % [kg] Participant body weight
subjectFootlength = [0.260; 0.286]; % [m] Participant foot length
anatomicalAngle = [-10-1,1.0966-1/180*pi;-15-1,1.0966-1/180*pi]; % [deg] Encoder angle w.r.t. anatomical angle for participants [7 4]
% SPAT settings
Settings.spatReps = 3; % [-] Number of SPAT slow/fast repetitions
% Sys-ID (D03) Perturbation
Settings.pertAmpl = 0.035; % [rad] Amplitude (peak-to-peak)
Settings.rngSeed = 1;      % [-] Random-number generator seed
% Filter settings
Settings.fcLpPos = 200;    % [Hz] Low-pass filter position for visualization
% Length of (bio)mechanical data segments
Settings.tSegStart = 0.04; % [s] Time before zero/onset
Settings.tSegEnd   = 0.4;  % [s] Time after zero/onset
% Torque normalization
Settings.isLocalTqNorm = 1; % Flag to normalize torque at start trial (if true) or with InitialTorque of session (if false)
Settings.isLocalPosNorm = 0; % Flag to normalize position at start trial (if true) or around the anatomical angles (if false)

% Create cell array of all perturbation characteristics to be sorted for
Settings.sortFields = {'rise','step'};
% Add folder with all shared functions
addpath(genpath('Functions'));
rng(Settings.rngSeed);

for ii = 1:numel(Settings.subjectID)
    %% Load & Process data
    %%% SPAT (Analyze first session as typical session)
    for jj = numel(Settings.sessionID):-1:1
        % Retrieve all experimental folders/files
        dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
        dataCD = dataCD(1:fileSepIdxs(end)-1);
        dirContent = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/*.mat']);
        dirContent = {dirContent.name}';
        dirCalibration = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/A05_CaliAchilles/*.mat']);
        dirCalibration = {dirCalibration.name}';
        
        % Load (bio)mechanical
        dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/' dirContent{1}];
        [DataMechSlow,Settings] = loadData(dataSet,Settings,anatomicalAngle(ii,:));
        [posRisingSlow,tqRisingSlow] = isolateRisingSlope(DataMechSlow,Settings);
        % Compensate for potential mismatch in number of samples
        posRisingSlow = cellfun(@(x) x(1:min(cellfun(@numel,posRisingSlow))),posRisingSlow,'UniformOutput',false);
        tqRisingSlow = cellfun(@(x) x(1:min(cellfun(@numel,tqRisingSlow))),tqRisingSlow,'UniformOutput',false);

        % Load (bio)mechanical
        dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/R03_QuadraticAsymROM/' dirContent{2}];
        [DataMechFast,~] = loadData(dataSet,Settings,anatomicalAngle(ii,:));
        [posRisingFast,tqRisingFast] = isolateRisingSlope(DataMechFast,Settings);
        % Compensate for potential mismatch in number of samples
        posRisingFast = cellfun(@(x) x(1:min(cellfun(@numel,posRisingFast))),posRisingFast,'UniformOutput',false);
        tqRisingFast = cellfun(@(x) x(1:min(cellfun(@numel,tqRisingFast))),tqRisingFast,'UniformOutput',false);
        
        % Load (bio)mechanical data from calibration trial
        dataCalibration = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/A05_CaliAchilles/' dirCalibration{1}];
        Settings.isLocalTqNorm = 0;
        [DataCalib,Settings] = loadData(dataCalibration,Settings,anatomicalAngle(ii,:));
        Settings.isLocalTqNorm = 1;
        % Pre-process calibration torque (low-pass filter & zero at starting angle of SPAT)
        [tqFilt.b,tqFilt.a] = butter(2,5*2*DataCalib.dt,'low');
        DataCalib.tqCalib = filtfilt(tqFilt.b,tqFilt.a,DataCalib.tqMeas);
        [~,idxCalib] = unique(DataCalib.posMeas); idxCalib = sort(idxCalib);
        DataCalib.tqCalib = DataCalib.tqCalib - interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),DataMechSlow.posMeas(1));
        % Interpolate calibration torque onto slow/fast movements
        calibTqSlowInterp = cellfun(@(x) interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),x),posRisingSlow,'UniformOutput',false);
        calibTqFastInterp = cellfun(@(x) interp1(DataCalib.posMeas(idxCalib),DataCalib.tqCalib(idxCalib),x),posRisingFast,'UniformOutput',false);
        
        % Foot-Gravity model
        footWeight = 0.0143*subjectWeight(ii);
        footCGArm = subjectFootlength(ii)*0.45;
        footTqSlow = cellfun(@(x) footWeight*9.81*(-footCGArm*sin(x)),posRisingSlow,'UniformOutput',false);
        footTqFast = cellfun(@(x) footWeight*9.81*(-footCGArm*sin(x)),posRisingFast,'UniformOutput',false);
        
        % Compensate Slow/Fast torque profiles
        tqRisingSlowComp = cellfun(@(y,a,b) y-a-b+b(1),tqRisingSlow,calibTqSlowInterp,footTqSlow,'UniformOutput',false);
        tqRisingFastComp = cellfun(@(y,a,b) y-a-b+b(1),tqRisingFast,calibTqFastInterp,footTqFast,'UniformOutput',false);
        
        % Compute difference Fast-Slow (interpolated for visualization)
        meanPosSlow = mean(cat(2,posRisingSlow{:}),2);
        meanPosFast = mean(cat(2,posRisingFast{:}),2);
        meanTqSlow = mean(cat(2,tqRisingSlowComp{:}),2);
        meanTqFast = mean(cat(2,tqRisingFastComp{:}),2);
        % Interpolate torque response of slow movement onto fast movement
        meanTqSlowInterp = interp1(meanPosSlow,meanTqSlow,meanPosFast,[],'extrap');
        
        meanPosDiff{jj,1} = meanPosFast;
        meanTqDiff{jj,1} = meanTqFast - meanTqSlowInterp;
    end

    %%% Impedance (Analyze first session as typical session)
    for jj = numel(Settings.sessionID):-1:1
        % Retrieve all experimental folders/files
        dirContent = dir([dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/D03_OfflineTIIdent/*.mat']);
        dirContent = {dirContent.name}';
        dataSet = [dataCD '/Data/Subject' Settings.subjectID{ii} '_Session' Settings.sessionID{jj} '/D03_OfflineTIIdent/' dirContent{1}];
        % Load (bio)mechanical
        [DataMech,Settings] = loadData(dataSet,Settings,anatomicalAngle(ii,:));

        % Align and sort the (bio)mechanical data
        DataMechAlign = DataMech;
        DataMechAlign.posRef = DataMechAlign.posRef - DataMechAlign.posRef(1) - Settings.pertAmpl/2;
        DataMechAlign.posMeas = DataMechAlign.posMeas - DataMechAlign.posMeas(1) - Settings.pertAmpl/2;
        MechEns{jj} = alignSortMechData(DataMechAlign,Settings);
    end

    %% Figure 2-3 (MeasuredSignals: SPATSignals & PCSignals)
    % Settings
    plotWidth    = 12.4;
    plotHeight   = 13;
    marginLeft   = 1.6;
    marginRight  = 0.15;
    marginBottom = 1;
    marginTop    = 0.35;
    nPlotX       = 2;
    nPlotY       = 5;
    spacingX     = 0.8;
    spacingY     = 1.1;
    fontSize     = 8;
    fontName     = 'Segoe UI';
    hAx = gobjects(8,1);
    condMarkers  = {'-','--','-.'};
    plotIntens = [plotColors(ii,'light'); plotColors(ii); plotColors(ii,'dark')];
    edgeIntens = [plotColors(ii,8); plotColors(ii,'light'); plotColors(ii)];
    fillIntens = [plotColors(ii,'lightest'); mean([plotColors(ii,'lightest'); plotColors(ii,'light')]);  plotColors(ii,'light')];

    if (ii == 1)
        figure('Units','centimeters','Position',[4 4 plotWidth plotHeight],'Color','w');
        posSubplots = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY);
    end
    %%% Figure 2
    %%% SPAT
    hAx(8+ii) = axes('position',posSubplots{8+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
        patch([min(mean(cat(2,posRisingSlow{:}),2)); max(mean(cat(2,posRisingSlow{:}),2)); flipud(mean(cat(2,posRisingSlow{:}),2))]*180/pi,[0; 0; flipud(mean(cat(2,tqRisingSlowComp{:}),2))],plotColors(ii,9),'EdgeColor','none');
        patch([mean(cat(2,posRisingSlow{:}),2); flipud(mean(cat(2,posRisingFast{:}),2))]*180/pi,[mean(cat(2,tqRisingSlowComp{:}),2); flipud(mean(cat(2,tqRisingFastComp{:}),2))],plotColors(ii,8),'EdgeColor','none');
        plot(mean(cat(2,posRisingSlow{:}),2)*180/pi,mean(cat(2,tqRisingSlowComp{:}),2),'--','Color',plotColors(ii,'light'),'LineWidth',1)
        plot(mean(cat(2,posRisingFast{:}),2)*180/pi,mean(cat(2,tqRisingFastComp{:}),2),'Color',plotColors(ii),'LineWidth',1)
        plot([0 0]+anatomicalAngle(ii,1),[-30 0],'-.','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        plot([Settings.pertAmpl Settings.pertAmpl]*180/pi+anatomicalAngle(ii,1),[-30 0],'-.','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        if (ii == 1), hYLabel(1) = ylabel({'Torque (Nm)'}); end
        xticks(-35:5:-5)
        axis([-37.5 -2.5 -30 0]);
    %%% SPAT Ensembles
    hAx(6+ii) = axes('position',posSubplots{6+ii}+[0 0.02 0 0],'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
        for jj = 1:numel(Settings.sessionID)
            plot(meanPosDiff{jj}*180/pi,meanTqDiff{jj},condMarkers{jj},'Color',plotIntens(jj,:),'LineWidth',1)
        end
        plot([0 0]+anatomicalAngle(ii,1),[-30 0],'-.','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        plot([Settings.pertAmpl Settings.pertAmpl]*180/pi+anatomicalAngle(ii,1),[-30 0],'-.','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        xlabel('PF\leftarrow Angle (deg) \rightarrowDF');
        if (ii == 1), hYLabel(2) = ylabel({'{\Delta}Torque (Nm)'}); end
        xticks(-35:5:-5)
        axis([-37.5 -2.5 -20 0]);
        if (ii == 1)
            [hLgd,hLgdIcons] = legend({'T0: {\Delta}W=0.054','T1: {\Delta}W=0.026','T2: {\Delta}W=0.029'},'FontSize',fontSize,'FontName',fontName,'Color','none','Box','off');
            hLgd.Position(1:2) = [0.135 0.686];
        else
            [hLgd,hLgdIcons] = legend({'T0: {\Delta}W=0.020','T1: {\Delta}W=0.014','T2: {\Delta}W=0.014'},'FontSize',fontSize,'FontName',fontName,'Color','none','Box','off');
            hLgd.Position(1:2) = [0.595 0.686];
        end
        for jj = 1:3
            hLgdIcons(2*jj+2).XData = hLgdIcons(2*jj+2).XData - [0 0.17];
            hLgdIcons(jj).Position(1) = hLgdIcons(jj).Position(1) - 0.17;
        end
        
    %%% Figure 3
    %%% Impedance Timeseries
    xLimits = [19.2 22.3; 8.5 11.6];
    hAx(4+ii) = axes('position',posSubplots{4+ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
        plot(xLimits(ii,:),[0 0]+anatomicalAngle(ii,1),'-.','Color',plotColors(10,'light'),'LineWidth',1,'HandleVisibility','off');
        plot(xLimits(ii,:),[2 2]+anatomicalAngle(ii,1),'-.','Color',plotColors(10,'light'),'LineWidth',1,'HandleVisibility','off');
        plot(DataMech.t,DataMech.posMeas*180/pi,'Color',plotColors(ii),'LineWidth',1)
        if (ii == 1), hYLabel(3) = ylabel({'Angle','PF\leftarrow (deg) \rightarrowDF'}); end
        axis([xLimits(ii,:) -0.1+anatomicalAngle(ii,1) 2.1+anatomicalAngle(ii,1)])
    hAx(2+ii) = axes('position',posSubplots{2+ii}+[0 0.02 0 0],'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
        plot(xLimits(ii,:),[0 0],'--','Color',plotColors(10,'light'),'HandleVisibility','off');
        plot(DataMech.t,DataMech.tqMeas,'Color',plotColors(ii),'LineWidth',1)
        xlabel('Time (s)')
        if (ii == 1), hYLabel(4) = ylabel({'Torque','PF\leftarrow (Nm) \rightarrowDF'}); end
        axis([xLimits(ii,:) -10 10])
	% Plot manipulations & Add perturbation onset lines across entire set of subplots
    visualStretches = find(MechEns{1}.StretchIdxs.rise > xLimits(ii,1)*2048 & MechEns{1}.StretchIdxs.rise < xLimits(ii,2)*2048);
    for jj = [2 4]+ii
        if (jj > 6), set(hAx(jj),'XTickLabel',[]); end
        for kk = 1:numel(visualStretches)
            plot(hAx(jj),[DataMech.t(MechEns{1}.StretchIdxs.rise(visualStretches(kk))) DataMech.t(MechEns{1}.StretchIdxs.rise(visualStretches(kk)))],get(hAx(jj),'ylim'),'--','Color',plotColors(10),'LineWidth',1);
        end
    end
    %%% Impedance Ensembles
    hAx(ii) = axes('position',posSubplots{ii},'FontSize',fontSize,'FontName',fontName,'Layer','top'); hold on; box off;
        plot([-Settings.tSegStart Settings.tSegEnd],[0 0],'--','Color',plotColors(10,'light'),'HandleVisibility','off');
        plot([0 0],[-11 5],'--','Color',plotColors(10),'LineWidth',1,'HandleVisibility','off');
        for jj = 1:numel(Settings.sessionID)
            shadedErrorBar(MechEns{jj}.tSeg,mean(MechEns{jj}.step.tq - mean(MechEns{jj}.step.tq((MechEns{jj}.tSeg < 0),:)),2),std(MechEns{jj}.step.tq - mean(MechEns{jj}.step.tq((MechEns{jj}.tSeg < 0),:)),[],2),plotIntens(jj,:),'none',fillIntens(jj,:),condMarkers{jj},'LineWidth',1)
        end
        xlabel('Time after perturbation (s)')
        if (ii == 1), hYLabel(5) = ylabel('Torque (Nm)'); end
        axis([-Settings.tSegStart Settings.tSegEnd -11 5])
        if (ii == 1)
            [hLgd,hLgdIcons] = legend({'T0: G=43','T1: G=14','T2: G=24'},'Orientation','horizontal','FontSize',fontSize,'FontName',fontName,'Color','none','Box','off');
            hLgd.Position(1:2) = [0.09 0.186];
        else
            [hLgd,hLgdIcons] = legend({'T0: G=2','T1: G=4','T2: G=7'},'Orientation','horizontal','FontSize',fontSize,'FontName',fontName,'Color','none','Box','off');
            hLgd.Position(1:2) = [0.565 0.186];
        end
        for jj = 1:3
            hLgdIcons(2*jj+2).XData = hLgdIcons(2*jj+2).XData - [0 0.075] - 0.075*(jj-1);
            hLgdIcons(jj).Position(1) = hLgdIcons(jj).Position(1) - 0.075*jj;
        end
end
for ii = 3:4, hYLabel(ii).Position(1) = 18.79; end %#ok<SAGROW>

% export_fig([cd '/Processed/OutcomeFigures/Fig2_SPATSignals_Fig3_PCSignals'],'-pdf','-painters')